"use strict";
/**
 * @module frest-json
 */
/**
 *    Copyright 2018 Panjie Setiawan Wicaksono
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
var ids_1 = require("./ids");
/**
 * Create a JSON error interceptor.
 *
 * @remarks
 * In Frest, any kind of error, including non-OK HTTP status, during request
 * life-cycle will be thrown. This interceptor will try to parse response body
 * in case the request is completed but with non-OK HTTP status **AND** it
 * specifies the `Content-Type` header is compatible with `application/json`
 * or the one specified in the options.
 *
 * @param opts - Options for this error interceptor.
 *
 * @returns JSON error interceptor function
 */
function errorInterceptor(opts) {
    if (opts === void 0) { opts = {}; }
    var jsonErrorInterceptor = function (err) {
        return new Promise(function (resolve, reject) {
            var headerContent = opts.headerContent;
            var response = err.response, request = err.request;
            var skip = request.skip;
            if (response) {
                var _a = response.origin, headers = _a.headers, bodyUsed = _a.bodyUsed;
                var ct = headers.get('Content-Type');
                if (ct &&
                    ct.indexOf(headerContent || 'application/json') >= 0 &&
                    (!skip || skip.indexOf(ids_1.ID_ERROR) < 0) &&
                    !bodyUsed) {
                    response.origin.json().then(function (body) {
                        response.body = body;
                        err.response = response;
                        reject(err);
                    });
                    return;
                }
            }
            resolve(null);
        });
    };
    Object.defineProperty(jsonErrorInterceptor, 'id', { value: ids_1.ID_ERROR });
    return jsonErrorInterceptor;
}
exports.default = errorInterceptor;
